:mod:`lck.django.score.models`
================================

.. automodule:: lck.django.score.models

Classes
-------

.. autoclass:: TotalScore
   :show-inheritance:
   :members:
   :member-order: bysource
   :content: both

.. autoclass:: Vote
   :show-inheritance:
   :members:
   :member-order: bysource
   :content: both
